@@ -40,30 +40,29 @@ G_BEGIN_DECLS
 #define COUCHDB_IS_DOCUMENT_CLASS(klass)     (G_TYPE_CHECK_CLASS_TYPE ((klass), COUCHDB_TYPE_DOCUMENT))
 #define COUCHDB_DOCUMENT_GET_CLASS(obj)      (G_TYPE_INSTANCE_GET_CLASS ((obj), COUCHDB_TYPE_DOCUMENT, CouchdbDocumentClass))
 
+typedef struct _CouchdbDocumentPrivate CouchdbDocumentPrivate;
+
+typedef struct {
+	GObject parent;
+	CouchdbDocumentPrivate *priv;
+} CouchdbDocument;
+
 typedef struct {
 	GObjectClass parent_class;
 } CouchdbDocumentClass;
 
 
-GType            couchdb_document_get_type (void);
+GType               couchdb_document_get_type (void);
 
-CouchdbDocument *couchdb_document_new (CouchdbSession  *couchdb);
-CouchdbDocument *couchdb_document_get (CouchdbSession  *couchdb,
-				       const char      *dbname,
-				       const char      *docid,
-				       GError          **error);
-gboolean         couchdb_document_put (CouchdbDocument *document,
-				       const char      *dbname,
-				       GError **error);
-gboolean         couchdb_document_delete (CouchdbDocument *document, GError **error);
+CouchdbDocument    *couchdb_document_new (void);
 
-const char      *couchdb_document_get_id (CouchdbDocument *document);
-void             couchdb_document_set_id (CouchdbDocument *document, const char *id);
-const char      *couchdb_document_get_revision (CouchdbDocument *document);
-void             couchdb_document_set_revision (CouchdbDocument *document, const char *revision);
+const char         *couchdb_document_get_id (CouchdbDocument *document);
+void                couchdb_document_set_id (CouchdbDocument *document, const char *id);
+const char         *couchdb_document_get_revision (CouchdbDocument *document);
+void                couchdb_document_set_revision (CouchdbDocument *document, const char *revision);
 
-gboolean         couchdb_document_has_field (CouchdbDocument *document, const char *field);
-void             couchdb_document_remove_field (CouchdbDocument *document, const char *field);
+gboolean            couchdb_document_has_field (CouchdbDocument *document, const char *field);
+void                couchdb_document_remove_field (CouchdbDocument *document, const char *field);
 
 CouchdbArrayField  *couchdb_document_get_array_field (CouchdbDocument *document, const char *field);
 void                couchdb_document_set_array_field (CouchdbDocument *document, const char *field, CouchdbArrayField *value);
@@ -78,7 +77,7 @@ void                couchdb_document_set_string_field (CouchdbDocument *document
 CouchdbStructField *couchdb_document_get_struct_field (CouchdbDocument *document, const char *field);
 void                couchdb_document_set_struct_field (CouchdbDocument *document, const char *field, CouchdbStructField *value);
       
-char             *couchdb_document_to_string (CouchdbDocument *document);
+char               *couchdb_document_to_string (CouchdbDocument *document);
 
 G_END_DECLS
 
