@@ -25,10 +25,12 @@
 #define __COUCHDB_GLIB_H__
 
 #include <couchdb-types.h>
+#include <couchdb-array-field.h>
 #include <couchdb-credentials.h>
 #include <couchdb-database-info.h>
+#include <couchdb-database.h>
+#include <couchdb-design-document.h>
 #include <couchdb-document.h>
-#include <couchdb-document-contact.h>
 #include <couchdb-document-info.h>
 #include <couchdb-session.h>
 #include <couchdb-struct-field.h>
