@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- * Copyright (C) 2009 Canonical Services Ltd (www.canonical.com)
+ * Copyright (C) 2009-2010 Canonical Services Ltd (www.canonical.com)
  *               2009 Mikkel Kamstrup Erlandsen
  *
  * Authors: Rodrigo Moya <rodrigo.moya@canonical.com>
@@ -26,7 +26,6 @@
 
 #include <glib.h>
 #include <glib-object.h>
-#include <json-glib/json-glib.h>
 #include "couchdb-types.h"
 #include "couchdb-credentials.h"
 #include "couchdb-database-info.h"
@@ -41,6 +40,7 @@ G_BEGIN_DECLS
 #define COUCHDB_SESSION_GET_CLASS(obj)      (G_TYPE_INSTANCE_GET_CLASS ((obj), COUCHDB_TYPE_SESSION, CouchdbSessionClass))
 
 typedef struct _CouchdbSessionPrivate CouchdbSessionPrivate;
+typedef struct _CouchdbDatabase CouchdbDatabase;
 
 typedef struct {
 	GObject parent;
@@ -51,14 +51,14 @@ typedef struct {
 typedef struct {
 	GObjectClass parent_class;
 
+	/* Signals */
 	void (* authentication_failed) (CouchdbSession *session);
 
 	void (* database_created) (CouchdbSession *session, const char *dbname);
 	void (* database_deleted) (CouchdbSession *session, const char *dbname);
 
-	void (* document_created) (CouchdbSession *session, const char *dbname, CouchdbDocument *document);
-	void (* document_updated) (CouchdbSession *session, const char *dbname, CouchdbDocument *document);
-	void (* document_deleted) (CouchdbSession *session, const char *dbname, const char *docid);
+	/* Virtual methods */
+	CouchdbDatabase * (* get_database) (CouchdbSession *session, const char *dbname);
 } CouchdbSessionClass;
 
 GType                couchdb_session_get_type (void);
@@ -71,27 +71,15 @@ void                 couchdb_session_free_database_list (GSList *dblist);
 
 CouchdbDatabaseInfo *couchdb_session_get_database_info (CouchdbSession *session, const char *dbname, GError **error);
 
+CouchdbDatabase     *couchdb_session_get_database (CouchdbSession *session, const char *dbname, GError **error);
 gboolean             couchdb_session_create_database (CouchdbSession *session, const char *dbname, GError **error);
 gboolean             couchdb_session_delete_database (CouchdbSession *session, const char *dbname, GError **error);
 gboolean             couchdb_session_compact_database (CouchdbSession *session, const char *dbname, GError **error);
 
-void                 couchdb_session_listen_for_changes (CouchdbSession *session, const char *dbname);
-
 void                 couchdb_session_enable_authentication (CouchdbSession *session, CouchdbCredentials *credentials);
 void                 couchdb_session_disable_authentication (CouchdbSession *session);
 gboolean             couchdb_session_is_authentication_enabled (CouchdbSession *session);
 
-gboolean             couchdb_session_send_message (CouchdbSession *session,
-						   const char *method,
-						   const char *url,
-						   const char *body,
-						   JsonParser *output,
-						   GError **error);
-
-GSList              *couchdb_session_list_documents (CouchdbSession *session, const char *dbname, GError **error);
-GSList              *couchdb_session_get_all_documents (CouchdbSession *session, const char *dbname, GError **error);
-void                 couchdb_session_free_document_list (GSList *doclist);
-
 gboolean             couchdb_session_replicate (CouchdbSession *session,
 						const gchar *source,
 						const gchar *target,
