@@ -22,316 +22,317 @@
 #include "desktopcouch-document-contact.h"
 #include "utils.h"
 
-CouchdbDocument *
-desktopcouch_document_contact_new (CouchdbSession *couchdb)
+G_DEFINE_TYPE(DesktopcouchDocumentContact, desktopcouch_document_contact, DESKTOPCOUCH_TYPE_DOCUMENT)
+
+static void
+desktopcouch_document_contact_class_init (DesktopcouchDocumentContactClass *klass)
 {
-	CouchdbDocument *document;
-
-	g_return_val_if_fail (COUCHDB_IS_SESSION (couchdb), NULL);
-
-	document = couchdb_document_new (couchdb);
-	if (document)
-		desktopcouch_document_set_record_type (document, DESKTOPCOUCH_RECORD_TYPE_CONTACT);
-
-	return document;
 }
 
-gboolean
-desktopcouch_document_is_contact (CouchdbDocument *document)
+static void
+desktopcouch_document_contact_init (DesktopcouchDocumentContact *document)
 {
-	g_return_val_if_fail (COUCHDB_IS_DOCUMENT (document), FALSE);
+	desktopcouch_document_set_record_type (DESKTOPCOUCH_DOCUMENT (document), DESKTOPCOUCH_RECORD_TYPE_CONTACT);
+}
 
-	return !g_ascii_strcasecmp (desktopcouch_document_get_record_type (document),
-				    DESKTOPCOUCH_RECORD_TYPE_CONTACT);
+/**
+ * desktopcouch_document_contact_new:
+ *
+ * Create a new #DesktopcouchDocumentContact object.
+ */
+DesktopcouchDocumentContact *
+desktopcouch_document_contact_new (void)
+{
+	return g_object_new (DESKTOPCOUCH_TYPE_DOCUMENT_CONTACT, NULL);
 }
 
 const char *
-desktopcouch_document_contact_get_title (CouchdbDocument *document)
+desktopcouch_document_contact_get_title (DesktopcouchDocumentContact *document)
 {
-	g_return_val_if_fail (COUCHDB_IS_DOCUMENT (document), NULL);
-	g_return_val_if_fail (desktopcouch_document_is_contact (document), NULL);
+	g_return_val_if_fail (DESKTOPCOUCH_IS_DOCUMENT_CONTACT (document), NULL);
+	g_return_val_if_fail (desktopcouch_document_is_contact (DESKTOPCOUCH_DOCUMENT (document)), NULL);
 
-	return couchdb_document_get_string_field (document, "title");
+	return couchdb_document_get_string_field (COUCHDB_DOCUMENT (document), "title");
 }
 
 void
-desktopcouch_document_contact_set_title (CouchdbDocument *document, const char *title)
+desktopcouch_document_contact_set_title (DesktopcouchDocumentContact *document, const char *title)
 {
-      	g_return_if_fail (COUCHDB_IS_DOCUMENT (document));
-	g_return_if_fail (desktopcouch_document_is_contact (document));
+      	g_return_if_fail (DESKTOPCOUCH_IS_DOCUMENT_CONTACT (document));
+	g_return_if_fail (desktopcouch_document_is_contact (DESKTOPCOUCH_DOCUMENT (document)));
 	g_return_if_fail (title != NULL);
 
-	couchdb_document_set_string_field (document, "title", title);
+	couchdb_document_set_string_field (COUCHDB_DOCUMENT (document), "title", title);
 }
 
 const char *
-desktopcouch_document_contact_get_first_name (CouchdbDocument *document)
+desktopcouch_document_contact_get_first_name (DesktopcouchDocumentContact *document)
 {
-	g_return_val_if_fail (COUCHDB_IS_DOCUMENT (document), NULL);
-	g_return_val_if_fail (desktopcouch_document_is_contact (document), NULL);
+	g_return_val_if_fail (DESKTOPCOUCH_IS_DOCUMENT_CONTACT (document), NULL);
+	g_return_val_if_fail (desktopcouch_document_is_contact (DESKTOPCOUCH_DOCUMENT (document)), NULL);
 
-	return couchdb_document_get_string_field (document, "first_name");
+	return couchdb_document_get_string_field (COUCHDB_DOCUMENT (document), "first_name");
 }
 
 void
-desktopcouch_document_contact_set_first_name (CouchdbDocument *document, const char *first_name)
+desktopcouch_document_contact_set_first_name (DesktopcouchDocumentContact *document, const char *first_name)
 {
-	g_return_if_fail (COUCHDB_IS_DOCUMENT (document));
-	g_return_if_fail (desktopcouch_document_is_contact (document));
+	g_return_if_fail (DESKTOPCOUCH_IS_DOCUMENT_CONTACT (document));
+	g_return_if_fail (desktopcouch_document_is_contact (DESKTOPCOUCH_DOCUMENT (document)));
 	g_return_if_fail (first_name != NULL);
 
-	couchdb_document_set_string_field (document, "first_name", first_name);
+	couchdb_document_set_string_field (COUCHDB_DOCUMENT (document), "first_name", first_name);
 }
 
 const char *
-desktopcouch_document_contact_get_middle_name (CouchdbDocument *document)
+desktopcouch_document_contact_get_middle_name (DesktopcouchDocumentContact *document)
 {
-	g_return_val_if_fail (COUCHDB_IS_DOCUMENT (document), NULL);
-	g_return_val_if_fail (desktopcouch_document_is_contact (document), NULL);
+	g_return_val_if_fail (DESKTOPCOUCH_IS_DOCUMENT_CONTACT (document), NULL);
+	g_return_val_if_fail (desktopcouch_document_is_contact (DESKTOPCOUCH_DOCUMENT (document)), NULL);
 
-	return couchdb_document_get_string_field (document, "middle_name");
+	return couchdb_document_get_string_field (COUCHDB_DOCUMENT (document), "middle_name");
 }
 
 void
-desktopcouch_document_contact_set_middle_name (CouchdbDocument *document, const char *middle_name)
+desktopcouch_document_contact_set_middle_name (DesktopcouchDocumentContact *document, const char *middle_name)
 {
-	g_return_if_fail (COUCHDB_IS_DOCUMENT (document));
-	g_return_if_fail (desktopcouch_document_is_contact (document));
+	g_return_if_fail (DESKTOPCOUCH_IS_DOCUMENT_CONTACT (document));
+	g_return_if_fail (desktopcouch_document_is_contact (DESKTOPCOUCH_DOCUMENT (document)));
 	g_return_if_fail (middle_name != NULL);
 
-	couchdb_document_set_string_field (document, "middle_name", middle_name);
+	couchdb_document_set_string_field (COUCHDB_DOCUMENT (document), "middle_name", middle_name);
 }
 
 const char *
-desktopcouch_document_contact_get_last_name (CouchdbDocument *document)
+desktopcouch_document_contact_get_last_name (DesktopcouchDocumentContact *document)
 {
-	g_return_val_if_fail (COUCHDB_IS_DOCUMENT (document), NULL);
-	g_return_val_if_fail (desktopcouch_document_is_contact (document), NULL);
+	g_return_val_if_fail (DESKTOPCOUCH_IS_DOCUMENT_CONTACT (document), NULL);
+	g_return_val_if_fail (desktopcouch_document_is_contact (DESKTOPCOUCH_DOCUMENT (document)), NULL);
 
-	return couchdb_document_get_string_field (document, "last_name");
+	return couchdb_document_get_string_field (COUCHDB_DOCUMENT (document), "last_name");
 }
 
 void
-desktopcouch_document_contact_set_last_name (CouchdbDocument *document, const char *last_name)
+desktopcouch_document_contact_set_last_name (DesktopcouchDocumentContact *document, const char *last_name)
 {
-      	g_return_if_fail (COUCHDB_IS_DOCUMENT (document));
-	g_return_if_fail (desktopcouch_document_is_contact (document));
+      	g_return_if_fail (DESKTOPCOUCH_IS_DOCUMENT_CONTACT (document));
+	g_return_if_fail (desktopcouch_document_is_contact (DESKTOPCOUCH_DOCUMENT (document)));
 	g_return_if_fail (last_name != NULL);
 
-	couchdb_document_set_string_field (document, "last_name", last_name);
+	couchdb_document_set_string_field (COUCHDB_DOCUMENT (document), "last_name", last_name);
 }
 
 const char *
-desktopcouch_document_contact_get_suffix (CouchdbDocument *document)
+desktopcouch_document_contact_get_suffix (DesktopcouchDocumentContact *document)
 {
-	g_return_val_if_fail (COUCHDB_IS_DOCUMENT (document), NULL);
-	g_return_val_if_fail (desktopcouch_document_is_contact (document), NULL);
+	g_return_val_if_fail (DESKTOPCOUCH_IS_DOCUMENT_CONTACT (document), NULL);
+	g_return_val_if_fail (desktopcouch_document_is_contact (DESKTOPCOUCH_DOCUMENT (document)), NULL);
 
-	return couchdb_document_get_string_field (document, "suffix");
+	return couchdb_document_get_string_field (COUCHDB_DOCUMENT (document), "suffix");
 }
 
 void
-desktopcouch_document_contact_set_suffix (CouchdbDocument *document, const char *suffix)
+desktopcouch_document_contact_set_suffix (DesktopcouchDocumentContact *document, const char *suffix)
 {
-      	g_return_if_fail (COUCHDB_IS_DOCUMENT (document));
-	g_return_if_fail (desktopcouch_document_is_contact (document));
+      	g_return_if_fail (DESKTOPCOUCH_IS_DOCUMENT_CONTACT (document));
+	g_return_if_fail (desktopcouch_document_is_contact (DESKTOPCOUCH_DOCUMENT (document)));
 	g_return_if_fail (suffix != NULL);
 
-	couchdb_document_set_string_field (document, "suffix", suffix);
+	couchdb_document_set_string_field (COUCHDB_DOCUMENT (document), "suffix", suffix);
 }
 
 const char *
-desktopcouch_document_contact_get_nick_name (CouchdbDocument *document)
+desktopcouch_document_contact_get_nick_name (DesktopcouchDocumentContact *document)
 {
-	g_return_val_if_fail (COUCHDB_IS_DOCUMENT (document), NULL);
-	g_return_val_if_fail (desktopcouch_document_is_contact (document), NULL);
+	g_return_val_if_fail (DESKTOPCOUCH_IS_DOCUMENT_CONTACT (document), NULL);
+	g_return_val_if_fail (desktopcouch_document_is_contact (DESKTOPCOUCH_DOCUMENT (document)), NULL);
 
-	return couchdb_document_get_string_field (document, "nick_name");
+	return couchdb_document_get_string_field (COUCHDB_DOCUMENT (document), "nick_name");
 }
 
 void
-desktopcouch_document_contact_set_nick_name (CouchdbDocument *document, const char *nick_name)
+desktopcouch_document_contact_set_nick_name (DesktopcouchDocumentContact *document, const char *nick_name)
 {
-      	g_return_if_fail (COUCHDB_IS_DOCUMENT (document));
-	g_return_if_fail (desktopcouch_document_is_contact (document));
+      	g_return_if_fail (DESKTOPCOUCH_IS_DOCUMENT_CONTACT (document));
+	g_return_if_fail (desktopcouch_document_is_contact (DESKTOPCOUCH_DOCUMENT (document)));
 	g_return_if_fail (nick_name != NULL);
 
-	couchdb_document_set_string_field (document, "nick_name", nick_name);
+	couchdb_document_set_string_field (COUCHDB_DOCUMENT (document), "nick_name", nick_name);
 }
 
 const char *
-desktopcouch_document_contact_get_spouse_name (CouchdbDocument *document)
+desktopcouch_document_contact_get_spouse_name (DesktopcouchDocumentContact *document)
 {
-	g_return_val_if_fail (COUCHDB_IS_DOCUMENT (document), NULL);
-	g_return_val_if_fail (desktopcouch_document_is_contact (document), NULL);
+	g_return_val_if_fail (DESKTOPCOUCH_IS_DOCUMENT_CONTACT (document), NULL);
+	g_return_val_if_fail (desktopcouch_document_is_contact (DESKTOPCOUCH_DOCUMENT (document)), NULL);
 
-	return couchdb_document_get_string_field (document, "spouse_name");
+	return couchdb_document_get_string_field (COUCHDB_DOCUMENT (document), "spouse_name");
 }
 
 void
-desktopcouch_document_contact_set_spouse_name (CouchdbDocument *document, const char *spouse_name)
+desktopcouch_document_contact_set_spouse_name (DesktopcouchDocumentContact *document, const char *spouse_name)
 {
-      	g_return_if_fail (COUCHDB_IS_DOCUMENT (document));
-	g_return_if_fail (desktopcouch_document_is_contact (document));
+      	g_return_if_fail (DESKTOPCOUCH_IS_DOCUMENT_CONTACT (document));
+	g_return_if_fail (desktopcouch_document_is_contact (DESKTOPCOUCH_DOCUMENT (document)));
 	g_return_if_fail (spouse_name != NULL);
 
-	couchdb_document_set_string_field (document, "spouse_name", spouse_name);
+	couchdb_document_set_string_field (COUCHDB_DOCUMENT (document), "spouse_name", spouse_name);
 }
 
 const char *
-desktopcouch_document_contact_get_birth_date (CouchdbDocument *document)
+desktopcouch_document_contact_get_birth_date (DesktopcouchDocumentContact *document)
 {
 	JsonObject *object;
 
-	g_return_val_if_fail (COUCHDB_IS_DOCUMENT (document), NULL);
-	g_return_val_if_fail (desktopcouch_document_is_contact (document), NULL);
+	g_return_val_if_fail (DESKTOPCOUCH_IS_DOCUMENT_CONTACT (document), NULL);
+	g_return_val_if_fail (desktopcouch_document_is_contact (DESKTOPCOUCH_DOCUMENT (document)), NULL);
 
-	return couchdb_document_get_string_field (document, "birth_date");
+	return couchdb_document_get_string_field (COUCHDB_DOCUMENT (document), "birth_date");
 }
 
 void
-desktopcouch_document_contact_set_birth_date (CouchdbDocument *document, const char *birth_date)
+desktopcouch_document_contact_set_birth_date (DesktopcouchDocumentContact *document, const char *birth_date)
 {
-	g_return_if_fail (COUCHDB_IS_DOCUMENT (document));
-	g_return_if_fail (desktopcouch_document_is_contact (document));
+	g_return_if_fail (DESKTOPCOUCH_IS_DOCUMENT_CONTACT (document));
+	g_return_if_fail (desktopcouch_document_is_contact (DESKTOPCOUCH_DOCUMENT (document)));
 	g_return_if_fail (birth_date != NULL);
 
-	couchdb_document_set_string_field (document, "birth_date", birth_date);
+	couchdb_document_set_string_field (COUCHDB_DOCUMENT (document), "birth_date", birth_date);
 }
 
 const char *
-desktopcouch_document_contact_get_wedding_date (CouchdbDocument *document)
+desktopcouch_document_contact_get_wedding_date (DesktopcouchDocumentContact *document)
 {
 	JsonObject *object;
 
-	g_return_val_if_fail (COUCHDB_IS_DOCUMENT (document), NULL);
-	g_return_val_if_fail (desktopcouch_document_is_contact (document), NULL);
+	g_return_val_if_fail (DESKTOPCOUCH_IS_DOCUMENT_CONTACT (document), NULL);
+	g_return_val_if_fail (desktopcouch_document_is_contact (DESKTOPCOUCH_DOCUMENT (document)), NULL);
 
-	return couchdb_document_get_string_field (document, "wedding_date");
+	return couchdb_document_get_string_field (COUCHDB_DOCUMENT (document), "wedding_date");
 }
 
 void
-desktopcouch_document_contact_set_wedding_date (CouchdbDocument *document, const char *wedding_date)
+desktopcouch_document_contact_set_wedding_date (DesktopcouchDocumentContact *document, const char *wedding_date)
 {
-	g_return_if_fail (COUCHDB_IS_DOCUMENT (document));
-	g_return_if_fail (desktopcouch_document_is_contact (document));
+	g_return_if_fail (DESKTOPCOUCH_IS_DOCUMENT_CONTACT (document));
+	g_return_if_fail (desktopcouch_document_is_contact (DESKTOPCOUCH_DOCUMENT (document)));
 	g_return_if_fail (wedding_date != NULL);
 
-	couchdb_document_set_string_field (document, "wedding_date", wedding_date);
+	couchdb_document_set_string_field (COUCHDB_DOCUMENT (document), "wedding_date", wedding_date);
 }
 
 const char *
-desktopcouch_document_contact_get_company (CouchdbDocument *document)
+desktopcouch_document_contact_get_company (DesktopcouchDocumentContact *document)
 {
-	g_return_val_if_fail (COUCHDB_IS_DOCUMENT (document), NULL);
-	g_return_val_if_fail (desktopcouch_document_is_contact (document), NULL);
+	g_return_val_if_fail (DESKTOPCOUCH_IS_DOCUMENT_CONTACT (document), NULL);
+	g_return_val_if_fail (desktopcouch_document_is_contact (DESKTOPCOUCH_DOCUMENT (document)), NULL);
 
-	return couchdb_document_get_string_field (document, "company");
+	return couchdb_document_get_string_field (COUCHDB_DOCUMENT (document), "company");
 }
 
 void
-desktopcouch_document_contact_set_company (CouchdbDocument *document, const char *company)
+desktopcouch_document_contact_set_company (DesktopcouchDocumentContact *document, const char *company)
 {
-      	g_return_if_fail (COUCHDB_IS_DOCUMENT (document));
-	g_return_if_fail (desktopcouch_document_is_contact (document));
+      	g_return_if_fail (DESKTOPCOUCH_IS_DOCUMENT_CONTACT (document));
+	g_return_if_fail (desktopcouch_document_is_contact (DESKTOPCOUCH_DOCUMENT (document)));
 	g_return_if_fail (company != NULL);
 
-	couchdb_document_set_string_field (document, "company", company);
+	couchdb_document_set_string_field (COUCHDB_DOCUMENT (document), "company", company);
 }
 
 const char *
-desktopcouch_document_contact_get_department (CouchdbDocument *document)
+desktopcouch_document_contact_get_department (DesktopcouchDocumentContact *document)
 {
-	g_return_val_if_fail (COUCHDB_IS_DOCUMENT (document), NULL);
-	g_return_val_if_fail (desktopcouch_document_is_contact (document), NULL);
+	g_return_val_if_fail (DESKTOPCOUCH_IS_DOCUMENT_CONTACT (document), NULL);
+	g_return_val_if_fail (desktopcouch_document_is_contact (DESKTOPCOUCH_DOCUMENT (document)), NULL);
 
-	return couchdb_document_get_string_field (document, "department");
+	return couchdb_document_get_string_field (COUCHDB_DOCUMENT (document), "department");
 }
 
 void
-desktopcouch_document_contact_set_department (CouchdbDocument *document, const char *department)
+desktopcouch_document_contact_set_department (DesktopcouchDocumentContact *document, const char *department)
 {
-      	g_return_if_fail (COUCHDB_IS_DOCUMENT (document));
-	g_return_if_fail (desktopcouch_document_is_contact (document));
+      	g_return_if_fail (DESKTOPCOUCH_IS_DOCUMENT_CONTACT (document));
+	g_return_if_fail (desktopcouch_document_is_contact (DESKTOPCOUCH_DOCUMENT (document)));
 	g_return_if_fail (department != NULL);
 
-	couchdb_document_set_string_field (document, "department", department);
+	couchdb_document_set_string_field (COUCHDB_DOCUMENT (document), "department", department);
 }
 
 const char *
-desktopcouch_document_contact_get_job_title (CouchdbDocument *document)
+desktopcouch_document_contact_get_job_title (DesktopcouchDocumentContact *document)
 {
-	g_return_val_if_fail (COUCHDB_IS_DOCUMENT (document), NULL);
-	g_return_val_if_fail (desktopcouch_document_is_contact (document), NULL);
+	g_return_val_if_fail (DESKTOPCOUCH_IS_DOCUMENT_CONTACT (document), NULL);
+	g_return_val_if_fail (desktopcouch_document_is_contact (DESKTOPCOUCH_DOCUMENT (document)), NULL);
 
-	return couchdb_document_get_string_field (document, "job_title");
+	return couchdb_document_get_string_field (COUCHDB_DOCUMENT (document), "job_title");
 }
 
 void
-desktopcouch_document_contact_set_job_title (CouchdbDocument *document, const char *job_title)
+desktopcouch_document_contact_set_job_title (DesktopcouchDocumentContact *document, const char *job_title)
 {
-      	g_return_if_fail (COUCHDB_IS_DOCUMENT (document));
-	g_return_if_fail (desktopcouch_document_is_contact (document));
+      	g_return_if_fail (DESKTOPCOUCH_IS_DOCUMENT_CONTACT (document));
+	g_return_if_fail (desktopcouch_document_is_contact (DESKTOPCOUCH_DOCUMENT (document)));
 	g_return_if_fail (job_title != NULL);
 
-	couchdb_document_set_string_field (document, "job_title", job_title);
+	couchdb_document_set_string_field (COUCHDB_DOCUMENT (document), "job_title", job_title);
 }
 
 const char *
-desktopcouch_document_contact_get_manager_name (CouchdbDocument *document)
+desktopcouch_document_contact_get_manager_name (DesktopcouchDocumentContact *document)
 {
-	g_return_val_if_fail (COUCHDB_IS_DOCUMENT (document), NULL);
-	g_return_val_if_fail (desktopcouch_document_is_contact (document), NULL);
+	g_return_val_if_fail (DESKTOPCOUCH_IS_DOCUMENT_CONTACT (document), NULL);
+	g_return_val_if_fail (desktopcouch_document_is_contact (DESKTOPCOUCH_DOCUMENT (document)), NULL);
 
-	return couchdb_document_get_string_field (document, "manager_name");
+	return couchdb_document_get_string_field (COUCHDB_DOCUMENT (document), "manager_name");
 }
 
 void
-desktopcouch_document_contact_set_manager_name (CouchdbDocument *document, const char *manager_name)
+desktopcouch_document_contact_set_manager_name (DesktopcouchDocumentContact *document, const char *manager_name)
 {
-      	g_return_if_fail (COUCHDB_IS_DOCUMENT (document));
-	g_return_if_fail (desktopcouch_document_is_contact (document));
+      	g_return_if_fail (DESKTOPCOUCH_IS_DOCUMENT_CONTACT (document));
+	g_return_if_fail (desktopcouch_document_is_contact (DESKTOPCOUCH_DOCUMENT (document)));
 	g_return_if_fail (manager_name != NULL);
 
-	couchdb_document_set_string_field (document, "manager_name", manager_name);
+	couchdb_document_set_string_field (COUCHDB_DOCUMENT (document), "manager_name", manager_name);
 }
 
 const char *
-desktopcouch_document_contact_get_assistant_name (CouchdbDocument *document)
+desktopcouch_document_contact_get_assistant_name (DesktopcouchDocumentContact *document)
 {
-	g_return_val_if_fail (COUCHDB_IS_DOCUMENT (document), NULL);
-	g_return_val_if_fail (desktopcouch_document_is_contact (document), NULL);
+	g_return_val_if_fail (DESKTOPCOUCH_IS_DOCUMENT_CONTACT (document), NULL);
+	g_return_val_if_fail (desktopcouch_document_is_contact (DESKTOPCOUCH_DOCUMENT (document)), NULL);
 
-	return couchdb_document_get_string_field (document, "assistant_name");
+	return couchdb_document_get_string_field (COUCHDB_DOCUMENT (document), "assistant_name");
 }
 
 void
-desktopcouch_document_contact_set_assistant_name (CouchdbDocument *document, const char *assistant_name)
+desktopcouch_document_contact_set_assistant_name (DesktopcouchDocumentContact *document, const char *assistant_name)
 {
-      	g_return_if_fail (COUCHDB_IS_DOCUMENT (document));
-	g_return_if_fail (desktopcouch_document_is_contact (document));
+      	g_return_if_fail (DESKTOPCOUCH_IS_DOCUMENT_CONTACT (document));
+	g_return_if_fail (desktopcouch_document_is_contact (DESKTOPCOUCH_DOCUMENT (document)));
 	g_return_if_fail (assistant_name != NULL);
 
-	couchdb_document_set_string_field (document, "assistant_name", assistant_name);
+	couchdb_document_set_string_field (COUCHDB_DOCUMENT (document), "assistant_name", assistant_name);
 }
 
 const char *
-desktopcouch_document_contact_get_office (CouchdbDocument *document)
+desktopcouch_document_contact_get_office (DesktopcouchDocumentContact *document)
 {
-	g_return_val_if_fail (COUCHDB_IS_DOCUMENT (document), NULL);
-	g_return_val_if_fail (desktopcouch_document_is_contact (document), NULL);
+	g_return_val_if_fail (DESKTOPCOUCH_IS_DOCUMENT_CONTACT (document), NULL);
+	g_return_val_if_fail (desktopcouch_document_is_contact (DESKTOPCOUCH_DOCUMENT (document)), NULL);
 
-	return couchdb_document_get_string_field (document, "office");
+	return couchdb_document_get_string_field (COUCHDB_DOCUMENT (document), "office");
 }
 
 void
-desktopcouch_document_contact_set_office (CouchdbDocument *document, const char *office)
+desktopcouch_document_contact_set_office (DesktopcouchDocumentContact *document, const char *office)
 {
-      	g_return_if_fail (COUCHDB_IS_DOCUMENT (document));
-	g_return_if_fail (desktopcouch_document_is_contact (document));
+      	g_return_if_fail (DESKTOPCOUCH_IS_DOCUMENT_CONTACT (document));
+	g_return_if_fail (desktopcouch_document_is_contact (DESKTOPCOUCH_DOCUMENT (document)));
 	g_return_if_fail (office != NULL);
 
-	couchdb_document_set_string_field (document, "office", office);
+	couchdb_document_set_string_field (COUCHDB_DOCUMENT (document), "office", office);
 }
 
 static void
@@ -354,7 +355,7 @@ foreach_object_cb (JsonObject *object,
 
 /**
  * desktopcouch_document_contact_get_email_addresses:
- * @document: A #CouchdbDocument object representing a contact
+ * @document: A #DesktopcouchDocumentContact object representing a contact
  *
  * Retrieve a list of email addresses from the specified contact document.
  * Email addresses are returned in a GSList of #CouchdbStructField objects,
@@ -366,16 +367,16 @@ foreach_object_cb (JsonObject *object,
  * Return value: a #GSList of #CouchdbStructField objects.
  */
 GSList *
-desktopcouch_document_contact_get_email_addresses (CouchdbDocument *document)
+desktopcouch_document_contact_get_email_addresses (DesktopcouchDocumentContact *document)
 {
 	GSList *list = NULL;
 	JsonObject *addresses_json;
 
-	g_return_val_if_fail (COUCHDB_IS_DOCUMENT (document), NULL);
-	g_return_val_if_fail (desktopcouch_document_is_contact (document), NULL);
+	g_return_val_if_fail (DESKTOPCOUCH_IS_DOCUMENT_CONTACT (document), NULL);
+	g_return_val_if_fail (desktopcouch_document_is_contact (DESKTOPCOUCH_DOCUMENT (document)), NULL);
 
 	addresses_json = json_object_get_object_member (
-		couchdb_document_get_json_object (document), "email_addresses");;
+		couchdb_document_get_json_object (COUCHDB_DOCUMENT (document)), "email_addresses");;
 	if (addresses_json) {
 		json_object_foreach_member (addresses_json,
 					    (JsonObjectForeach) foreach_object_cb,
@@ -386,12 +387,12 @@ desktopcouch_document_contact_get_email_addresses (CouchdbDocument *document)
 }
 
 void
-desktopcouch_document_contact_set_email_addresses (CouchdbDocument *document, GSList *list)
+desktopcouch_document_contact_set_email_addresses (DesktopcouchDocumentContact *document, GSList *list)
 {
 	GSList *l;
 	JsonObject *addresses_json;
 
-	g_return_if_fail (COUCHDB_IS_DOCUMENT (document));
+	g_return_if_fail (DESKTOPCOUCH_IS_DOCUMENT_CONTACT (document));
 
 	addresses_json = json_object_new ();
 	for (l = list; l != NULL; l = l->next) {
@@ -413,20 +414,22 @@ desktopcouch_document_contact_set_email_addresses (CouchdbDocument *document, GS
 		}
 	}
 
-	json_object_set_object_member (couchdb_document_get_json_object (document), "email_addresses", addresses_json);
+	json_object_set_object_member (couchdb_document_get_json_object (COUCHDB_DOCUMENT (document)),
+				       "email_addresses",
+				       addresses_json);
 }
 
 GSList *
-desktopcouch_document_contact_get_phone_numbers (CouchdbDocument *document)
+desktopcouch_document_contact_get_phone_numbers (DesktopcouchDocumentContact *document)
 {
 	GSList *list = NULL;
 	JsonObject *phone_numbers;
 
-	g_return_val_if_fail (COUCHDB_IS_DOCUMENT (document), NULL);
-	g_return_val_if_fail (desktopcouch_document_is_contact (document), NULL);
+	g_return_val_if_fail (DESKTOPCOUCH_IS_DOCUMENT_CONTACT (document), NULL);
+	g_return_val_if_fail (desktopcouch_document_is_contact (DESKTOPCOUCH_DOCUMENT (document)), NULL);
 
 	phone_numbers = json_object_get_object_member (
-		couchdb_document_get_json_object (document), "phone_numbers");
+		couchdb_document_get_json_object (COUCHDB_DOCUMENT (document)), "phone_numbers");
 	if (phone_numbers) {
 		json_object_foreach_member (phone_numbers,
 					    (JsonObjectForeach) foreach_object_cb,
@@ -437,12 +440,12 @@ desktopcouch_document_contact_get_phone_numbers (CouchdbDocument *document)
 }
 
 void
-desktopcouch_document_contact_set_phone_numbers (CouchdbDocument *document, GSList *list)
+desktopcouch_document_contact_set_phone_numbers (DesktopcouchDocumentContact *document, GSList *list)
 {
 	GSList *l;
 	JsonObject *phone_numbers;
 
-	g_return_if_fail (COUCHDB_IS_DOCUMENT (document));
+	g_return_if_fail (DESKTOPCOUCH_IS_DOCUMENT_CONTACT (document));
 
 	phone_numbers = json_object_new ();
 	for (l = list; l != NULL; l = l->next) {
@@ -466,20 +469,21 @@ desktopcouch_document_contact_set_phone_numbers (CouchdbDocument *document, GSLi
 		}
 	}
 
-	json_object_set_object_member (couchdb_document_get_json_object (document), "phone_numbers", phone_numbers);
+	json_object_set_object_member (couchdb_document_get_json_object (COUCHDB_DOCUMENT (document)),
+				       "phone_numbers", phone_numbers);
 }
 
 GSList *
-desktopcouch_document_contact_get_addresses (CouchdbDocument *document)
+desktopcouch_document_contact_get_addresses (DesktopcouchDocumentContact *document)
 {
 	GSList *list = NULL;
 	JsonObject *addresses;
 
-	g_return_val_if_fail (COUCHDB_IS_DOCUMENT (document), NULL);
-	g_return_val_if_fail (desktopcouch_document_is_contact (document), NULL);
+	g_return_val_if_fail (DESKTOPCOUCH_IS_DOCUMENT_CONTACT (document), NULL);
+	g_return_val_if_fail (desktopcouch_document_is_contact (DESKTOPCOUCH_DOCUMENT (document)), NULL);
 
 	addresses = json_object_get_object_member (
-		couchdb_document_get_json_object (document), "addresses");
+		couchdb_document_get_json_object (COUCHDB_DOCUMENT (document)), "addresses");
 	if (addresses) {
 		json_object_foreach_member (addresses,
 					    (JsonObjectForeach) foreach_object_cb,
@@ -490,12 +494,12 @@ desktopcouch_document_contact_get_addresses (CouchdbDocument *document)
 }
 
 void
-desktopcouch_document_contact_set_addresses (CouchdbDocument *document, GSList *list)
+desktopcouch_document_contact_set_addresses (DesktopcouchDocumentContact *document, GSList *list)
 {
 	GSList *l;
 	JsonObject *addresses;
 
-	g_return_if_fail (COUCHDB_IS_DOCUMENT (document));
+	g_return_if_fail (DESKTOPCOUCH_IS_DOCUMENT_CONTACT (document));
 
 	addresses = json_object_new ();
 	for (l = list; l != NULL; l = l->next) {
@@ -530,20 +534,21 @@ desktopcouch_document_contact_set_addresses (CouchdbDocument *document, GSList *
 		}
 	}
 
-	json_object_set_object_member (couchdb_document_get_json_object (document), "addresses", addresses);
+	json_object_set_object_member (couchdb_document_get_json_object (COUCHDB_DOCUMENT (document)),
+				       "addresses", addresses);
 }
 
 GSList *
-desktopcouch_document_contact_get_im_addresses (CouchdbDocument *document)
+desktopcouch_document_contact_get_im_addresses (DesktopcouchDocumentContact *document)
 {
 	GSList *list = NULL;
 	JsonObject *im_addresses;
 
-	g_return_val_if_fail (COUCHDB_IS_DOCUMENT (document), NULL);
-	g_return_val_if_fail (desktopcouch_document_is_contact (document), NULL);
+	g_return_val_if_fail (DESKTOPCOUCH_IS_DOCUMENT_CONTACT (document), NULL);
+	g_return_val_if_fail (desktopcouch_document_is_contact (DESKTOPCOUCH_DOCUMENT (document)), NULL);
 
 	im_addresses = json_object_get_object_member (
-		couchdb_document_get_json_object (document), "im_addresses");
+		couchdb_document_get_json_object (COUCHDB_DOCUMENT (document)), "im_addresses");
 	if (im_addresses != NULL) {
 		json_object_foreach_member (im_addresses,
 					    (JsonObjectForeach) foreach_object_cb,
@@ -554,12 +559,12 @@ desktopcouch_document_contact_get_im_addresses (CouchdbDocument *document)
 }
 
 void
-desktopcouch_document_contact_set_im_addresses (CouchdbDocument *document, GSList *list)
+desktopcouch_document_contact_set_im_addresses (DesktopcouchDocumentContact *document, GSList *list)
 {
 	GSList *l;
 	JsonObject *im_addresses_json;
 
-	g_return_if_fail (COUCHDB_IS_DOCUMENT (document));
+	g_return_if_fail (DESKTOPCOUCH_IS_DOCUMENT_CONTACT (document));
 
 	im_addresses_json = json_object_new ();
 	for (l = list; l != NULL; l = l->next) {
@@ -583,20 +588,21 @@ desktopcouch_document_contact_set_im_addresses (CouchdbDocument *document, GSLis
 		}
 	}
 
-	json_object_set_object_member (couchdb_document_get_json_object (document), "im_addresses", im_addresses_json);
+	json_object_set_object_member (couchdb_document_get_json_object (COUCHDB_DOCUMENT (document)),
+				       "im_addresses", im_addresses_json);
 }
 
 GSList *
-desktopcouch_document_contact_get_urls (CouchdbDocument *document)
+desktopcouch_document_contact_get_urls (DesktopcouchDocumentContact *document)
 {
 	GSList *list = NULL;
 	JsonObject *urls;
 
-	g_return_val_if_fail (COUCHDB_IS_DOCUMENT (document), NULL);
-	g_return_val_if_fail (desktopcouch_document_is_contact (document), NULL);
+	g_return_val_if_fail (DESKTOPCOUCH_IS_DOCUMENT_CONTACT (document), NULL);
+	g_return_val_if_fail (desktopcouch_document_is_contact (DESKTOPCOUCH_DOCUMENT (document)), NULL);
 
 	urls = json_object_get_object_member (
-		couchdb_document_get_json_object (document), "urls");
+		couchdb_document_get_json_object (COUCHDB_DOCUMENT (document)), "urls");
 	if (urls) {
 		json_object_foreach_member (urls,
 					    (JsonObjectForeach) foreach_object_cb,
@@ -607,12 +613,12 @@ desktopcouch_document_contact_get_urls (CouchdbDocument *document)
 }
 
 void
-desktopcouch_document_contact_set_urls (CouchdbDocument *document, GSList *list)
+desktopcouch_document_contact_set_urls (DesktopcouchDocumentContact *document, GSList *list)
 {
 	GSList *l;
 	JsonObject *urls_json;
 
-	g_return_if_fail (COUCHDB_IS_DOCUMENT (document));
+	g_return_if_fail (DESKTOPCOUCH_IS_DOCUMENT_CONTACT (document));
 
 	urls_json = json_object_new ();
 	for (l = list; l != NULL; l = l->next) {
@@ -634,53 +640,54 @@ desktopcouch_document_contact_set_urls (CouchdbDocument *document, GSList *list)
 		}
 	}
 
-	json_object_set_object_member (couchdb_document_get_json_object (document), "urls", urls_json);
+	json_object_set_object_member (couchdb_document_get_json_object (COUCHDB_DOCUMENT (document)),
+				       "urls", urls_json);
 }
 
 /**
  * desktopcouch_document_contact_get_categories:
- * @document: A #CouchdbDocument object
+ * @document: A #DesktopcouchDocumentContact object
  *
  * Get the list of categories (as a string) for this contact document.
  *
  * Return value: A comma separated list of categories as a string.
  */
 const char *
-desktopcouch_document_contact_get_categories (CouchdbDocument *document)
+desktopcouch_document_contact_get_categories (DesktopcouchDocumentContact *document)
 {
-	g_return_val_if_fail (COUCHDB_IS_DOCUMENT (document), NULL);
-	g_return_val_if_fail (desktopcouch_document_is_contact (document), NULL);
+	g_return_val_if_fail (DESKTOPCOUCH_IS_DOCUMENT_CONTACT (document), NULL);
+	g_return_val_if_fail (desktopcouch_document_is_contact (DESKTOPCOUCH_DOCUMENT (document)), NULL);
 
-	return couchdb_document_get_string_field (document, "categories");
+	return couchdb_document_get_string_field (COUCHDB_DOCUMENT (document), "categories");
 }
 
 void
-desktopcouch_document_contact_set_categories (CouchdbDocument *document, const char *categories)
+desktopcouch_document_contact_set_categories (DesktopcouchDocumentContact *document, const char *categories)
 {
-	g_return_if_fail (COUCHDB_IS_DOCUMENT (document));
-	g_return_if_fail (desktopcouch_document_is_contact (document));
+	g_return_if_fail (DESKTOPCOUCH_IS_DOCUMENT_CONTACT (document));
+	g_return_if_fail (desktopcouch_document_is_contact (DESKTOPCOUCH_DOCUMENT (document)));
 	g_return_if_fail (categories != NULL);
 
-	couchdb_document_set_string_field (document, "categories", categories);
+	couchdb_document_set_string_field (COUCHDB_DOCUMENT (document), "categories", categories);
 }
 
 const char *
-desktopcouch_document_contact_get_notes (CouchdbDocument *document)
+desktopcouch_document_contact_get_notes (DesktopcouchDocumentContact *document)
 {
-	g_return_val_if_fail (COUCHDB_IS_DOCUMENT (document), NULL);
-	g_return_val_if_fail (desktopcouch_document_is_contact (document), NULL);
+	g_return_val_if_fail (DESKTOPCOUCH_IS_DOCUMENT_CONTACT (document), NULL);
+	g_return_val_if_fail (desktopcouch_document_is_contact (DESKTOPCOUCH_DOCUMENT (document)), NULL);
 
-	return couchdb_document_get_string_field (document, "notes");
+	return couchdb_document_get_string_field (COUCHDB_DOCUMENT (document), "notes");
 }
 
 void
-desktopcouch_document_contact_set_notes (CouchdbDocument *document, const char *notes)
+desktopcouch_document_contact_set_notes (DesktopcouchDocumentContact *document, const char *notes)
 {
-	g_return_if_fail (COUCHDB_IS_DOCUMENT (document));
-	g_return_if_fail (desktopcouch_document_is_contact (document));
+	g_return_if_fail (DESKTOPCOUCH_IS_DOCUMENT_CONTACT (document));
+	g_return_if_fail (desktopcouch_document_is_contact (DESKTOPCOUCH_DOCUMENT (document)));
 	g_return_if_fail (notes != NULL);
 
-	couchdb_document_set_string_field (document, "notes", notes);
+	couchdb_document_set_string_field (COUCHDB_DOCUMENT (document), "notes", notes);
 }
 
 CouchdbStructField *
